cgexplore.molecular.GeneratedPrecursor
======================================

.. currentmodule:: cgexplore.molecular

.. autoclass:: GeneratedPrecursor
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~GeneratedPrecursor.get_building_block
      ~GeneratedPrecursor.get_smiles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GeneratedPrecursor.binder_beads
      ~GeneratedPrecursor.placer_beads
      ~GeneratedPrecursor.molecule
      ~GeneratedPrecursor.db_key
      ~GeneratedPrecursor.composition
   
   